@@ -6,6 +6,7 @@ import os
 import pathlib
 from functools import partial
 from multiprocessing.pool import Pool
+from time import sleep
 
 import click
 import humanize
@@ -20,7 +21,7 @@ from ..advanced.flows import FileUploadError, download_vrcdb_file, ReboticsClass
 from ..advanced.packers import ClassificationDatabasePacker, ClassificationDatabaseException, \
     DuplicateFeatureVectorsException, VirtualClassificationDatabasePacker
 from ..constants import RCDB
-from ..providers import AdminProvider, RetailerProvider, sleep
+from ..providers import AdminProvider, RetailerProvider
 from ..utils import Timer, uri_validator, download_and_return_id, get_filename_from_url
 
 
