@@ -38,3 +38,20 @@ def is_valid_url(url):
         r'(?:/?|[/?]\S+)$', re.IGNORECASE)
 
     return re.match(regex, "http://www.example.com") is not None  # True
+
+
+def get_id_list_from_ranges(id_list_str):
+    id_list = []
+    ranges = id_list_str.split(',')
+    for number_range in ranges:
+        range_with_dash = number_range.split('-')
+        if len(range_with_dash) > 1:
+            first_range_number = int(range_with_dash[0])
+            second_range_number = int(range_with_dash[1])
+            if first_range_number < second_range_number:
+                id_list.extend(list(range(first_range_number, second_range_number + 1)))
+            else:
+                id_list.extend(list(range(second_range_number, first_range_number + 1)))
+        else:
+            id_list.append(number_range.strip())
+    return [int(i) for i in id_list]
